#ifndef APPWIN_H
#define APPWIN_H

#include <qmainwindow.h>
#include <qpopupmenu.h>
#include <qtabwidget.h>

#include "pltwin.h"
#include "strings.h"


class AppWin: public QMainWindow
{
  Q_OBJECT

public:
  QPrinter *printer;
  QTabWidget *tabWidget;
  PltWin *plotWidget[MAX_PLOTS];

  QPopupMenu *mfile, *mexport, *mview, *mplot, *mlayers, *mtran, *mappear, *mhelp;

  int OpenID, SaveID, CloseID, CloseAllID, PrintID, ExportID, ExpXYZID, ExpCFGID, AnimateID, QuitID;
  int ZoomInID, ZoomOutID, FitWinID, PanRightID, PanLeftID, PanUpID, PanDownID;
  int SelPlotsID, PanFRightID, PanFLeftID, PanFUpID, PanFDownID;
  int UnrelViewID, RelViewID, CompViewID, MagDispID, NumAtomID, EdgeCompID;
  int ScrewCompID, DAtLayersID, DAtTypesID, InertAtomID, DCenterID, SPlanesID, ShowCSysID, 
    ShowCellsID, ShowGbID, RelaxInfoID;
  int ShowZLayID, SetZLayID;
  int CoordSysID, XFlipID, YFlipID, ZFlipID, TransformID, ProjVectID;
  int ScalePosID, ScaleArrID, ArrNeighID;
  int CrystPlotID, ArrPlotID, AboutID;

  AppWin();
  ~AppWin();

protected:
  void closeEvent( QCloseEvent* );
  virtual void resizeEvent( QResizeEvent * );

private slots:
  void about();
  void animate();
  void arrNeighbors();
  void arrowsPlot();
  bool coordSys();
  void close();
  void closeAll();
  void crystalPlot();
  void disloCenter();
  void enableMenuItems( bool flag );
  void exportCFG();
  void exportXYZ();
  void fitWin();
  void flipBlock( int id );
  void interpretCommand( QString cmd );
  bool loadFile( QString fn );
  void loadSettings();
  void open();
  void panRight();
  void panLeft();
  void panUp();
  void panDown();
  void panFastRight();
  void panFastLeft();
  void panFastUp();
  void panFastDown();
  void plotAtomLayers();
  void plotAtomTypes();
  void plotEdgeComponent();
  void plotScrewComponent();
  void plotUnrelaxed();
  void plotRelaxed();
  void plotComposite();
  void plotInertAtoms();
  void print();
  void printMagDisp();
  void printAtomNum();
  void projVector();
  void quit();
  void relaxInfo();
  void repaintStatusBar();
  void saveDD(); 
  void scaleArrow();
  void scalePos();
  void selectPlots();
  void selectZLayers();
  void showCells();
  void showCSys();
  void showGb();
  void showZLayers();
  void showPlanes();
  void transform();
  void zoomIn();  
  void zoomOut();
};

#endif
